
from lxml import etree
from odoo.addons.saas_trial.tests.common import TestTrialCommon, tagged
from odoo.addons.saas_worker.util import version_gte
from odoo.addons.saas_worker import metabase


@tagged('post_install', '-at_install', 'post_saas_trial_creation')
class TestTrialCustomDomainOnboarding(TestTrialCommon):

    def setUp(self):
        super().setUp()
        # remove existing custom domain
        for domain in metabase.get_domains(self.env.cr.dbname):
            metabase.remove_hostname(self.env.cr.dbname, domain)

        if version_gte("saas~16.4"):
            # reset current progress
            self.env["onboarding.progress.step"].search([]).unlink()
            self.onboarding_panel_url = "/onboarding/website_sale_dashboard"
        else:
            self.onboarding_panel_url = "/website_sale_dashboard/website_sale_dashboard_onboarding"

        # Reset admin-password (as it's randomnly generated on trial creation)
        self.user_admin.sudo().with_context(saas_force_oauth=True, no_update_notification=True).write({
            "password": self.user_admin.login
        })

    def test_custom_domain_onboarding(self):
        self.authenticate(self.user_admin.login, self.user_admin.login)

        # Ensure the step is shown
        resp = self.url_open(self.onboarding_panel_url, json={'params': {}})
        html_data = resp.json().get("result", {}).get("html", "")
        html_tree = etree.fromstring(html_data, parser=etree.HTMLParser())
        self.assertTrue(
            html_tree is not None and bool(html_tree.xpath(
                "//*[@data-method='action_open_account_onboarding_domain_name']" +
                ("/span" if version_gte("16.0") else "") +  # target child span after odoo/odoo@6e77e9c5a
                "[contains(text(), 'Set domain name')]"
            )),
            "Custom domain onboarding step not found in 'website_sale_dashboard' onboarding panel",
        )

        # Add a custom domain
        metabase.add_hostname(self.env.cr.dbname, "my-custom-domain.example.org")

        # Ensure the step is shown as completed
        resp = self.url_open(self.onboarding_panel_url, json={'params': {}})
        html_data = resp.json().get("result", {}).get("html", "")
        html_tree = etree.fromstring(html_data, parser=etree.HTMLParser())
        self.assertTrue(
            html_tree is not None and bool(html_tree.xpath(
                "//*[@data-method='action_open_account_onboarding_domain_name']" +
                "//*[contains(., 'Step Completed!')]"
            )),
            "Custom domain onboarding step should be displayed as completed",
        )
